@@ -5,7 +5,7 @@ if [[ $(pip3 show openvino-dev) ]]; then
          echo "openvino-dev is installed"
      else
          echo "Installing openvino-dev to download the models"
-         pip3 install openvino-dev==2021.4.2
+         sudo  pip3 install openvino-dev==2021.4.2
 fi
 
 omz_downloader --name age-gender-recognition-retail-0013
