@@ -1,3 +1,5 @@
 #!/bin/bash
-cd ~
+USER=/home/intel
+
+cd $USER
 sudo docker rmi media-analytics-pipeline-zoo
